#[non_exhaustive]pub struct ChannelModeratorRemoveV1 {
pub broadcaster_user_id: UserId,
}Available on crate feature
eventsub only.Expand description
channel.moderator.remove: a user has moderator privileges removed on a specified channel.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.broadcaster_user_id: UserIdGet notifications when a moderator is removed in this channel.
Implementations