#[non_exhaustive]pub struct ChannelUpdateV2 {
pub broadcaster_user_id: UserId,
}Available on crate feature
eventsub only.Expand description
channel.update subscription type sends notifications when a broadcaster updates the category, title, mature flag, or broadcast language for their channel.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.broadcaster_user_id: UserIdThe broadcaster user ID for the channel you want to get updates for.
Implementations
Sourceimpl ChannelUpdateV2
impl ChannelUpdateV2
Sourcepub fn broadcaster_user_id(broadcaster_user_id: impl Into<UserId>) -> Self
pub fn broadcaster_user_id(broadcaster_user_id: impl Into<UserId>) -> Self
The broadcaster user ID for the channel you want to get updates for.