#[non_exhaustive]pub enum SuspiciousUserType {
ManuallyAdded,
DetectedBanEvader,
DetectedSusChatter,
BannedInSharedChannel,
Unknown(String),
}Available on crate feature
helix only.Expand description
Traits of a suspicious user
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ManuallyAdded
A manually added user.
DetectedBanEvader
A detected ban evader.
DetectedSusChatter
A detected suspicious user.
A user banned in another channel that shares ban information.
Unknown(String)
An unknown user type, contains the raw string provided by Twitch.