#[non_exhaustive]pub struct DeleteChatMessagesRequest<'a> {
pub broadcaster_id: Cow<'a, UserIdRef>,
pub moderator_id: Cow<'a, UserIdRef>,
pub message_id: Option<Cow<'a, MsgIdRef>>,
}helix only.Expand description
Query Parameters for Delete Chat Messages
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.broadcaster_id: Cow<'a, UserIdRef>The ID of the broadcaster that owns the chat room to remove messages from.
moderator_id: Cow<'a, UserIdRef>The ID of a user that has permission to moderate the broadcaster’s chat room.
This ID must match the user ID in the OAuth token. If the broadcaster wants to remove messages themselves, set this parameter to the broadcaster’s ID, too.
message_id: Option<Cow<'a, MsgIdRef>>The ID of the message to remove.
The id tag in the PRIVMSG contains the message’s ID (see PRIVMSG Tags).
Restrictions
The message must have been created within the last 6 hours. The message must not belong to the broadcaster. The message must not belong to another moderator.
If not specified, the request removes all messages in the broadcaster’s chat room.
Implementations
Sourceimpl<'a> DeleteChatMessagesRequest<'a>
impl<'a> DeleteChatMessagesRequest<'a>
Sourcepub fn builder() -> DeleteChatMessagesRequestBuilder<'a, ((), (), ())>
pub fn builder() -> DeleteChatMessagesRequestBuilder<'a, ((), (), ())>
Create a builder for building DeleteChatMessagesRequest.
On the builder, call .broadcaster_id(...), .moderator_id(...), .message_id(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of DeleteChatMessagesRequest.
Sourceimpl<'a> DeleteChatMessagesRequest<'a>
impl<'a> DeleteChatMessagesRequest<'a>