#[non_exhaustive]pub struct UpdateCustomRewardBody<'a> {Show 14 fields
pub title: Option<Cow<'a, str>>,
pub prompt: Option<Cow<'a, str>>,
pub cost: Option<usize>,
pub background_color: Option<Cow<'a, str>>,
pub is_enabled: Option<bool>,
pub is_user_input_required: Option<bool>,
pub is_max_per_stream_enabled: Option<bool>,
pub max_per_stream: Option<usize>,
pub is_max_per_user_per_stream_enabled: Option<bool>,
pub max_per_user_per_stream: Option<usize>,
pub is_global_cooldown_enabled: Option<bool>,
pub global_cooldown_seconds: Option<usize>,
pub is_paused: Option<bool>,
pub should_redemptions_skip_request_queue: Option<bool>,
}helix only.Expand description
Body Parameters for Update Custom Rewards
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: Option<Cow<'a, str>>The title of the reward
prompt: Option<Cow<'a, str>>The prompt for the viewer when they are redeeming the reward
cost: Option<usize>The cost of the reward
background_color: Option<Cow<'a, str>>Custom background color for the reward. Format: Hex with # prefix. Example: #00E5CB.
is_enabled: Option<bool>Is the reward currently enabled, if false the reward won’t show up to viewers
is_user_input_required: Option<bool>Does the user need to enter information when redeeming the reward.
is_max_per_stream_enabled: Option<bool>Whether a maximum per stream is enabled
max_per_stream: Option<usize>The maximum number per stream if enabled
is_max_per_user_per_stream_enabled: Option<bool>Whether a maximum per user per stream is enabled. Defaults to false.
max_per_user_per_stream: Option<usize>The maximum number per user per stream if enabled
is_global_cooldown_enabled: Option<bool>Whether a cooldown is enabled. Defaults to false.
global_cooldown_seconds: Option<usize>The cooldown in seconds if enabled
is_paused: Option<bool>Is the reward currently paused, if true viewers can’t redeem
should_redemptions_skip_request_queue: Option<bool>Should redemptions be set to FULFILLED status immediately when redeemed and skip the request queue instead of the normal UNFULFILLED status.
Implementations
Sourceimpl<'a> UpdateCustomRewardBody<'a>
impl<'a> UpdateCustomRewardBody<'a>
Sourcepub fn builder() -> UpdateCustomRewardBodyBuilder<'a, ((), (), (), (), (), (), (), (), (), (), (), (), (), ())>
pub fn builder() -> UpdateCustomRewardBodyBuilder<'a, ((), (), (), (), (), (), (), (), (), (), (), (), (), ())>
Create a builder for building UpdateCustomRewardBody.
On the builder, call .title(...)(optional), .prompt(...)(optional), .cost(...)(optional), .background_color(...)(optional), .is_enabled(...)(optional), .is_user_input_required(...)(optional), .is_max_per_stream_enabled(...)(optional), .max_per_stream(...)(optional), .is_max_per_user_per_stream_enabled(...)(optional), .max_per_user_per_stream(...)(optional), .is_global_cooldown_enabled(...)(optional), .global_cooldown_seconds(...)(optional), .is_paused(...)(optional), .should_redemptions_skip_request_queue(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of UpdateCustomRewardBody.