#[non_exhaustive]pub struct Poll {
pub id: PollId,
pub broadcaster_id: UserId,
pub broadcaster_name: UserName,
pub broadcaster_login: DisplayName,
pub title: String,
pub choices: Vec<PollChoice>,
pub channel_points_voting_enabled: bool,
pub channel_points_per_vote: i64,
pub status: PollStatus,
pub duration: i64,
pub started_at: Timestamp,
pub ended_at: Option<Timestamp>,
}Available on crate feature
helix only.Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: PollIdID of the poll.
broadcaster_id: UserIdID of the broadcaster.
broadcaster_name: UserNameName of the broadcaster.
broadcaster_login: DisplayNameLogin of the broadcaster.
title: StringQuestion displayed for the poll.
choices: Vec<PollChoice>Array of the poll choices.
channel_points_voting_enabled: boolIndicates if Channel Points can be used for voting.
channel_points_per_vote: i64Number of Channel Points required to vote once with Channel Points.
status: PollStatusPoll status. Valid values are:
duration: i64Total duration for the poll (in seconds).
started_at: TimestampUTC timestamp for the poll’s start time.
ended_at: Option<Timestamp>UTC timestamp for the poll’s end time. Set to null if the poll is active.