#[non_exhaustive]pub struct Redemption {
pub channel_id: UserId,
pub id: RedemptionId,
pub redeemed_at: Timestamp,
pub reward: Reward,
pub status: RedemptionStatus,
pub user: User,
pub user_input: Option<String>,
pub cursor: Option<String>,
}use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
pubsub only.Expand description
A redemption users can “buy” with channel points to trigger rewards
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel_id: UserIduse EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
ID of channel where the redemption was triggered
id: RedemptionIduse EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
ID of the redemption. Also returned in twitch IRC
redeemed_at: Timestampuse EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Timestamp in which a reward was redeemed
reward: Rewarduse EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Data about the reward that was redeemed
status: RedemptionStatususe EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
reward redemption status, will be FULFILLED if a user skips the reward queue, UNFULFILLED otherwise. ACTION_TAKEN is for redemption-status-update
user: Useruse EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
User that triggered the reward
user_input: Option<String>use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
A string that the user entered if the reward requires input
cursor: Option<String>use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
A cursor for something