#[non_exhaustive]pub enum ModerationActionCommand {
Show 31 variants
Delete,
Timeout,
Untimeout,
Mod,
Unmod,
ModifiedAutomodProperties,
Ban,
Unban,
AutomodRejected,
ApproveAutomodMessage,
DeniedAutomodMessage,
Raid,
Unraid,
Slow,
SlowOff,
Followers,
FollowersOff,
Subscribers,
SubscribersOff,
EmoteOnly,
EmoteOnlyOff,
Clear,
R9KBeta,
R9KBetaOff,
Vip,
Unvip,
Host,
Unhost,
ApproveUnbanRequest,
DenyUnbanRequest,
DeleteNotification,
}use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
pubsub only.Expand description
A command
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Delete
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Delete
Given when a message is deleted with /delete <msg-id>
Timeout
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Timeout
Given when a user is timed-out with /timeout <user> <time> <reason>
Untimeout
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Untimeout
Given when a user is unbanned while under a timeout /untimeout <user> or /unban <user>
Mod
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Mod
Given when a user is added as a moderator. /mod <user>.
See ChatModeratorActionsReply::ModeratorAdded where this is given
Unmod
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Unmod
Given when a user is removed as a moderator, /unmod <user>
ModifiedAutomodProperties
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Modified automod properties
Given when automod config is changed. I.e filtering changed etc
Ban
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Ban
Given when a user is banned with /timeout <user> <reason>
Unban
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Unban
Given when a user is unbanned with /unban <user> or /untimeout <user>
AutomodRejected
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Automod message rejected
ApproveAutomodMessage
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Automod message approved
DeniedAutomodMessage
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Automod message denied
Raid
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Raid
Given when editor/broadcaster does /raid <channel>
Unraid
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Unraid
Given when editor/broadcaster does /unraid
Slow
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Slow-mode chat enabled
SlowOff
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Slow-mode chat disabled
Followers
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Followers-only chat enabled
FollowersOff
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Followers-only chat disabled
Subscribers
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Subscriber-only chat enabled
SubscribersOff
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Subscriber-only chat disabled
EmoteOnly
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Emote-only chat enabled
EmoteOnlyOff
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Emote-only chat disabled
Clear
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Chat cleared for all viewers
R9KBeta
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Unique chat enabled
R9KBetaOff
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Unique chat disabled
Vip
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
User added as VIP
See also: VipAdded, which isn’t the same event.
Unvip
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
User removed as VIP
Host
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Channel host started
Unhost
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Channel host removed
ApproveUnbanRequest
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Unban Request Approved
DenyUnbanRequest
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Unban Request Denied
DeleteNotification
use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Users own message was deleted.