Enum ModerationActionCommand

#[non_exhaustive]
pub enum ModerationActionCommand {
Show 31 variants Delete, Timeout, Untimeout, Mod, Unmod, ModifiedAutomodProperties, Ban, Unban, AutomodRejected, ApproveAutomodMessage, DeniedAutomodMessage, Raid, Unraid, Slow, SlowOff, Followers, FollowersOff, Subscribers, SubscribersOff, EmoteOnly, EmoteOnlyOff, Clear, R9KBeta, R9KBetaOff, Vip, Unvip, Host, Unhost, ApproveUnbanRequest, DenyUnbanRequest, DeleteNotification,
}
👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043
Available on crate feature pubsub only.
A command

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Delete

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Delete

Given when a message is deleted with /delete <msg-id>



Timeout

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Timeout

Given when a user is timed-out with /timeout <user> <time> <reason>



Untimeout

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Untimeout

Given when a user is unbanned while under a timeout /untimeout <user> or /unban <user>



Mod

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Mod

Given when a user is added as a moderator. /mod <user>.

See ChatModeratorActionsReply::ModeratorAdded where this is given



Unmod

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Unmod

Given when a user is removed as a moderator, /unmod <user>



ModifiedAutomodProperties

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Modified automod properties

Given when automod config is changed. I.e filtering changed etc



Ban

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Ban

Given when a user is banned with /timeout <user> <reason>



Unban

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Unban

Given when a user is unbanned with /unban <user> or /untimeout <user>



AutomodRejected

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Automod message rejected



ApproveAutomodMessage

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Automod message approved



DeniedAutomodMessage

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Automod message denied



Raid

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Raid

Given when editor/broadcaster does /raid <channel>



Unraid

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Unraid

Given when editor/broadcaster does /unraid



Slow

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Slow-mode chat enabled



SlowOff

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Slow-mode chat disabled



Followers

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Followers-only chat enabled



FollowersOff

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Followers-only chat disabled



Subscribers

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Subscriber-only chat enabled



SubscribersOff

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Subscriber-only chat disabled



EmoteOnly

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Emote-only chat enabled



EmoteOnlyOff

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Emote-only chat disabled



Clear

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Chat cleared for all viewers



R9KBeta

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Unique chat enabled



R9KBetaOff

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Unique chat disabled



Vip

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

User added as VIP

See also: VipAdded, which isn’t the same event.



Unvip

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

User removed as VIP



Host

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Channel host started



Unhost

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Channel host removed



ApproveUnbanRequest

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Unban Request Approved



DenyUnbanRequest

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Unban Request Denied



DeleteNotification

👎Deprecated since 0.7.0: use EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043

Users own message was deleted.