#[non_exhaustive]pub enum ModerationActionCommand {
Show 31 variants
Delete,
Timeout,
Untimeout,
Mod,
Unmod,
ModifiedAutomodProperties,
Ban,
Unban,
AutomodRejected,
ApproveAutomodMessage,
DeniedAutomodMessage,
Raid,
Unraid,
Slow,
SlowOff,
Followers,
FollowersOff,
Subscribers,
SubscribersOff,
EmoteOnly,
EmoteOnlyOff,
Clear,
R9KBeta,
R9KBetaOff,
Vip,
Unvip,
Host,
Unhost,
ApproveUnbanRequest,
DenyUnbanRequest,
DeleteNotification,
}EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043pubsub only.Expand description
A command
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Delete
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Delete
Given when a message is deleted with /delete <msg-id>
Timeout
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Timeout
Given when a user is timed-out with /timeout <user> <time> <reason>
Untimeout
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Untimeout
Given when a user is unbanned while under a timeout /untimeout <user> or /unban <user>
Mod
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Mod
Given when a user is added as a moderator. /mod <user>.
See ChatModeratorActionsReply::ModeratorAdded where this is given
Unmod
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Unmod
Given when a user is removed as a moderator, /unmod <user>
ModifiedAutomodProperties
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Modified automod properties
Given when automod config is changed. I.e filtering changed etc
Ban
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Ban
Given when a user is banned with /timeout <user> <reason>
Unban
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Unban
Given when a user is unbanned with /unban <user> or /untimeout <user>
AutomodRejected
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Automod message rejected
ApproveAutomodMessage
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Automod message approved
DeniedAutomodMessage
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Automod message denied
Raid
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Raid
Given when editor/broadcaster does /raid <channel>
Unraid
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Unraid
Given when editor/broadcaster does /unraid
Slow
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Slow-mode chat enabled
SlowOff
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Slow-mode chat disabled
Followers
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Followers-only chat enabled
FollowersOff
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Followers-only chat disabled
Subscribers
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Subscriber-only chat enabled
SubscribersOff
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Subscriber-only chat disabled
EmoteOnly
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Emote-only chat enabled
EmoteOnlyOff
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Emote-only chat disabled
Clear
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Chat cleared for all viewers
R9KBeta
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Unique chat enabled
R9KBetaOff
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Unique chat disabled
Vip
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043User added as VIP
See also: VipAdded, which isn’t the same event.
Unvip
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043User removed as VIP
Host
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Channel host started
Unhost
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Channel host removed
ApproveUnbanRequest
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Unban Request Approved
DenyUnbanRequest
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Unban Request Denied
DeleteNotification
EventSub instead, see https://discuss.dev.twitch.com/t/legacy-pubsub-deprecation-and-shutdown-timeline/58043Users own message was deleted.